using Marco.Pms.Model.Utilities;
using Marco.Pms.Model.ViewModels.Report;

namespace MarcoBMS.Services.Service
{
    public interface IEmailSender
    {
        //Task<string> GetEmailTemplate1();
        Task SendResetPasswordEmail(string toEmail, string userName, string resetLink);
        Task SendResetPasswordEmailOnRegister(string toEmail, string toName, string resetLink);
        Task SendResetPasswordSuccessEmail(string toEmail, string userName);
        Task SendRequestDemoEmail(List<string> toEmails, InquiryEmailObject demoEmailObject);
        Task SendEmailAsync(List<string> toEmails, string subject, string body);
        Task SendOTP(List<string> toEmails, string emailBody, string name, string otp, string subject);
        Task<string> SendProjectStatisticsEmail(List<string> toEmails, string emailBody, string subject, ProjectStatisticReport report);
    }
}
